cheesecake.logger.Message

Package cheesecake :: Module logger :: Class Message |
[hide private]
[frames] | no frames]

## Class Message
source code

    object --+
             |
            Message

Instance Methods | [hide private]
| __init__(self, keywords, args) x.__init__(...) initializes x; see x.__class__.__doc__ for signature
| content(self)
| prefix(self)
| __str__(self) str(x)
Inherited from `object`: `__delattr__`, `__getattribute__`, `__hash__`, `__new__`, `__reduce__`, `__reduce_ex__`, `__repr__`, `__setattr__`

Class Variables | [hide private]
Inherited from `object`: `__class__`

Method Details | [hide private]

### __init__(self, keywords, args) (Constructor) | source code
x.__init__(...) initializes x; see x.__class__.__doc__ for signature Overrides: object.__init__ (inherited documentation)

### content(self) | source code

### prefix(self) | source code

### __str__(self) (Informal representation operator) | source code
str(x) Overrides: object.__str__ (inherited documentation)